package com.ozs.web.controller.plan;

import com.ozs.common.core.controller.BaseController;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.core.domain.model.LoginUser;
import com.ozs.common.core.page.TableDataInfo;
import com.ozs.common.utils.poi.ExcelUtil;
import com.ozs.framework.web.service.TokenService;
import com.ozs.plan.doman.PlanYears;
import com.ozs.plan.doman.vo.requestVo.PlanYearsStandardVo;
import com.ozs.plan.service.PlanYearsService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 年度计划信息控制层
 *
 * @author buzhanyi
 */
@RestController
@RequestMapping("/plan/PlanYears")
public class PlanYearsController extends BaseController {
    @Autowired
    private PlanYearsService planYearsService;
    @Autowired
    private TokenService tokenService;

    @ApiOperation(value = "查询年度计划")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody PlanYearsStandardVo yearsStandardVo) {
        startPage();
        List<PlanYears> list = planYearsService.selectPlanYearsList(yearsStandardVo);
        return getDataTable(list);
    }

    @ApiOperation(value = "创建年度计划")
    @PostMapping("/add")
    public AjaxResult add(@RequestBody PlanYearsStandardVo yearsStandardVo, HttpServletRequest request) {
        //获取采购单位-
        LoginUser loginUser = tokenService.getLoginUser(request);
        yearsStandardVo.setPurchaseUnit(loginUser.getDeptId());
        yearsStandardVo.setCreateBy(String.valueOf(loginUser.getUserId()));
        return planYearsService.insertPlanYears(yearsStandardVo);
    }

    @ApiOperation(value = "修改年度计划")
    @PostMapping("/update")
    public AjaxResult update(@RequestBody PlanYearsStandardVo yearsStandardVo) {
        return planYearsService.update(yearsStandardVo);
    }

    @ApiOperation(value = "提交年度计划")
    @PostMapping("/commit")
    public AjaxResult commit(@RequestBody PlanYearsStandardVo yearsStandardVo) {
        return planYearsService.commit(yearsStandardVo);
    }

    @ApiOperation(value = "删除年度计划")
    @PostMapping("/delete")
    public AjaxResult delete(@RequestBody PlanYearsStandardVo yearsStandardVo) {
        return planYearsService.deletePlanYearsById(yearsStandardVo.getPlanYearId());
    }

    @ApiOperation(value = "根据id获取年度计划信息")
    @PostMapping("/view")
    public AjaxResult view(@RequestBody PlanYearsStandardVo yearsStandardVo) {
        return planYearsService.view(yearsStandardVo);
    }

    @ApiOperation(value = "审核年度计划通过")
    @PostMapping("/reviewTo")
    public AjaxResult reviewTo(@RequestBody PlanYearsStandardVo yearsStandardVo) {
        return planYearsService.reviewTo(yearsStandardVo);
    }

    @ApiOperation(value = "审核年度计划退回")
    @PostMapping("/reviewReturn")
    public AjaxResult reviewReturn(@RequestBody PlanYearsStandardVo yearsStandardVo) {
        return planYearsService.reviewReturn(yearsStandardVo);
    }

    @ApiOperation(value = "导入年度计划数据")
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception {
        ExcelUtil<PlanYears> util = new ExcelUtil<>(PlanYears.class);
        List<PlanYears> planYears = util.importExcel(file.getInputStream());
        String operName = getUsername();
        String message = planYearsService.importPlanYears(planYears, updateSupport, operName);
        return success(message);
    }


}
